@@ -1,4 +1,5 @@
 import os
+import shutil
 import tempfile
 import unittest
 from pathlib import Path
@@ -6,8 +7,6 @@ from pathlib import Path
 import dask.array
 import h5py
 import numpy as np
-import zarr.core
-from distributed import Client
 from tifffile import tifffile
 
 from aind_data_transfer.util.io_utils import (
@@ -27,7 +26,7 @@ def _write_test_tiffs(folder, n=1):
         a = np.ones(IM_SHAPE, dtype=IM_DTYPE)
         path = os.path.join(folder, f"data_{i}.tif")
         paths.append(path)
-        tifffile.imwrite(path, a)
+        tifffile.imwrite(path, a, imagej=True)
     return paths
 
 
@@ -45,19 +44,20 @@ def _write_test_h5(folder, n=1):
 
 class TestTiffReader(unittest.TestCase):
     def setUp(self):
-        self._temp_dir = tempfile.TemporaryDirectory()
-        self._image_dir = Path(self._temp_dir.name) / "images"
-        os.makedirs(self._image_dir, exist_ok=True)
+        self._image_dir = Path(__file__).parent / "resources/imaging/data/tiff"
+        self._image_dir.mkdir(parents=True, exist_ok=True)
         self._image_path = _write_test_tiffs(self._image_dir, n=1)[0]
-        self._reader = TiffReader(self._image_path)
+        # Create a unique directory for each test case, since the TiffReader will
+        # create a references file with the same name and the tests run concurrently.
+        # If you don't do this, you will get an exception saying the references file
+        # already exists.
+        self._refs_dir = tempfile.TemporaryDirectory()
+        self._reader = TiffReader(self._image_path, refs_dir=self._refs_dir.name)
 
     def tearDown(self) -> None:
         self._reader.close()
-        self._temp_dir.cleanup()
-
-    def test_constructor(self):
-        self.assertEqual(self._reader.filepath, self._image_path)
-        self.assertIsNotNone(self._reader.get_handle())
+        self._refs_dir.cleanup()
+        shutil.rmtree(self._image_dir)
 
     def test_get_filepath(self):
         self.assertEqual(self._image_path, self._reader.get_filepath())
@@ -76,13 +76,6 @@ class TestTiffReader(unittest.TestCase):
         self.assertTrue(np.all(d == 1))
         self.assertEqual(IM_DTYPE, d.dtype)
 
-    def test_as_zarr(self):
-        z = self._reader.as_zarr()
-        self.assertIsInstance(z, zarr.core.Array)
-        self.assertEqual(IM_SHAPE, z.shape)
-        self.assertTrue(np.all(z[:] == 1))
-        self.assertEqual(IM_DTYPE, z.dtype)
-
     def test_get_shape(self):
         self.assertEqual(IM_SHAPE, self._reader.get_shape())
 
@@ -92,17 +85,12 @@ class TestTiffReader(unittest.TestCase):
         self.assertTrue(all(isinstance(c, int) for c in chunks))
         self.assertTrue(all(c >= 1 for c in chunks))
 
+    def test_get_dtype(self):
+        self.assertEqual(IM_DTYPE, self._reader.get_dtype())
+
     def test_get_itemsize(self):
         self.assertEqual(2, self._reader.get_itemsize())
 
-    def test_get_handle(self):
-        self.assertIsNotNone(self._reader.get_handle())
-
-    def test_close(self):
-        self._reader.close()
-        self.assertIsNone(self._reader.handle)
-        self.assertRaises(AttributeError, self._reader.as_array)
-
 
 class TestHDF5Reader(unittest.TestCase):
     def setUp(self):
@@ -111,12 +99,10 @@ class TestHDF5Reader(unittest.TestCase):
         os.makedirs(self._image_dir, exist_ok=True)
         self._image_path = _write_test_h5(self._image_dir, n=1)[0]
         self._reader = ImarisReader(self._image_path)
-        self.client = Client()
 
     def tearDown(self) -> None:
         self._reader.close()
         self._temp_dir.cleanup()
-        self.client.close()
 
     def test_constructor(self):
         self.assertEqual(self._reader.filepath, self._image_path)
@@ -136,9 +122,9 @@ class TestHDF5Reader(unittest.TestCase):
     # def test_as_dask_array(self):
     #     d = self._reader.as_dask_array()
     #     self.assertIsInstance(d, dask.array.Array)
-    #     self.assertEqual(SHAPE, d.shape)
+    #     self.assertEqual(IM_SHAPE, d.shape)
     #     self.assertTrue(np.all(d == 1))
-    #     self.assertEqual(DTYPE, d.dtype)
+    #     self.assertEqual(IM_DTYPE, d.dtype)
 
     def test_get_shape(self):
         self.assertEqual(IM_SHAPE, self._reader.get_shape())
@@ -175,10 +161,12 @@ class TestDataReaderFactor(unittest.TestCase):
     def test_create_hdf5reader(self):
         reader = DataReaderFactory().create(self._h5_path)
         self.assertIsInstance(reader, ImarisReader)
+        reader.close()
 
     def test_create_tiffreader(self):
         reader = DataReaderFactory().create(self._tiff_path)
         self.assertIsInstance(reader, TiffReader)
+        reader.close()
 
 
 if __name__ == "__main__":
